@@ -6,9 +6,9 @@
 use v5.26;
 use utf8;
 
-use Object::Pad 0.70 ':experimental(init_expr adjust_params)';
+use Object::Pad 0.73 ':experimental(init_expr adjust_params)';
 
-package App::sdview::Parser 0.08;
+package App::sdview::Parser 0.09;
 role App::sdview::Parser;
 
 use String::Tagged;
@@ -24,14 +24,14 @@ class App::sdview::Para::Heading :strict(params) {
 
 class App::sdview::Para::Plain :strict(params) {
    field $text   :param :reader;
-   field $indent :param :reader { 0 };
+   field $indent :param :reader = 0;
 
    method type { "plain" }
 }
 
 class App::sdview::Para::Verbatim :strict(params) {
    field $text   :param :reader;
-   field $indent :param :reader { 0 };
+   field $indent :param :reader = 0;
 
    method type { "verbatim" }
 }
@@ -40,7 +40,7 @@ class App::sdview::Para::List :strict(params) {
    # "bullet" | "number" | "text"
    field $listtype :param :reader;
    field $indent   :param :reader;
-   field $initial  :param :reader { 1 };  # for number lists
+   field $initial  :param :reader = 1;  # for number lists
 
    field @items           :reader;
 
@@ -51,7 +51,7 @@ class App::sdview::Para::List :strict(params) {
 
 class App::sdview::Para::ListItem :strict(params) {
    field $listtype :param :reader;
-   field $term     :param :reader { undef };
+   field $term     :param :reader = undef;
    field $text     :param :reader;
 
    method type { "item" }
